@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#!/usr/bin/python3.11
 
 # SPDX-License-Identifier: GPL-3.0-or-later
 # SPDX-FileCopyrightText: 2010  Darwin M. Bautista <djclue917@gmail.com>
@@ -30,7 +30,7 @@ ANY_PORT       = 'any'
 ANY_PROTOCOL   = 'any'
 OLD_DESCR_FILE = "/etc/ufw/descriptions"
 DESCR_FILE     = "/etc/kcm_ufw/descriptions"
-DEFAULTS_FILE  = "share/kcm_ufw/defaults"
+DEFAULTS_FILE  = "/kcm_ufw/defaults"
 
 ERROR_FAILED_TO_SET_STATUS      = -1
 ERROR_INVALID_INDEX             = -2
